import cv2
import os

# 导出视频的每一帧为图片序列
def export_frames(video_path, output_folder):
    # 打开视频文件
    video = cv2.VideoCapture(video_path)
    
    # 确保视频文件成功打开
    if not video.isOpened():
        print("无法打开视频文件")
        return
    
    # 创建输出文件夹（如果不存在）
    if not os.path.exists(output_folder):
        os.makedirs(output_folder)
    
    # 逐帧导出为图片序列
    frame_count = 1  # 从1开始命名
    fps = video.get(cv2.CAP_PROP_FPS)
    print(f"视频帧率: {fps}")
    while True:
        # 读取当前帧
        ret, frame = video.read()
        
        # 检查是否成功读取帧
        if not ret:
            break
        
        # 构造输出文件路径
        output_path = os.path.join(output_folder, f"frame_{frame_count}.jpg")
        
        # 保存当前帧为图像文件
        cv2.imwrite(output_path, frame)
        
        frame_count += 1
      
    
    # 释放视频对象
    video.release()
    
    print("图片序列导出完成")
  

# 示例用法

video_path = "example.mp4"
output_folder ="output_frames" #注意路径名须为英文

export_frames(video_path, output_folder)